summaryrefslogtreecommitdiffstats
path: root/krusader
diff options
context:
space:
mode:
Diffstat (limited to 'krusader')
-rw-r--r--krusader/Konfigurator/kgdependencies.cpp2
-rw-r--r--krusader/Makefile.am4
-rw-r--r--krusader/UserAction/kraction.cpp10
-rw-r--r--krusader/krslots.cpp6
4 files changed, 11 insertions, 11 deletions
diff --git a/krusader/Konfigurator/kgdependencies.cpp b/krusader/Konfigurator/kgdependencies.cpp
index 4c56fb8..a9f2c96 100644
--- a/krusader/Konfigurator/kgdependencies.cpp
+++ b/krusader/Konfigurator/kgdependencies.cpp
@@ -59,7 +59,7 @@ KgDependencies::KgDependencies( bool first, TQWidget* parent, const char* name
addApplication( "df", pathsGrid, 0, general_tab, PAGE_GENERAL );
addApplication( "eject", pathsGrid, 1, general_tab, PAGE_GENERAL );
- addApplication( "kdesu", pathsGrid, 2, general_tab, PAGE_GENERAL );
+ addApplication( "tdesu", pathsGrid, 2, general_tab, PAGE_GENERAL );
addApplication( "kget", pathsGrid, 3, general_tab, PAGE_GENERAL );
addApplication( "kmail", pathsGrid, 4, general_tab, PAGE_GENERAL );
addApplication( "diff utility", pathsGrid, 5, general_tab, PAGE_GENERAL );
diff --git a/krusader/Makefile.am b/krusader/Makefile.am
index 4920404..76cce08 100644
--- a/krusader/Makefile.am
+++ b/krusader/Makefile.am
@@ -102,13 +102,13 @@ krusader_LDADD = \
$(LIB_KDECORE) \
$(LIB_QT) \
$(LIBSOCKET) \
- -lkdefx \
+ -ltdefx \
-lkutils \
-lkwalletclient
# the library search path.
-krusader_LDFLAGS = $(all_libraries) $(kde_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lkwalletclient
+krusader_LDFLAGS = $(all_libraries) $(kde_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lkwalletclient
###########################################################
diff --git a/krusader/krslots.cpp b/krusader/krslots.cpp
index fcd7ade..afd323a 100644
--- a/krusader/krslots.cpp
+++ b/krusader/krslots.cpp
@@ -542,14 +542,14 @@ void KRslots::multiRename(){
void KRslots::rootKrusader()
{
- if( !KrServices::cmdExist( "krusader" ) || !KrServices::cmdExist( "kdesu" ) )
+ if( !KrServices::cmdExist( "krusader" ) || !KrServices::cmdExist( "tdesu" ) )
{
- KMessageBox::sorry( krApp, i18n( "Can't start root mode krusader, because krusader or kdesu is missing from the path. Please configure the dependencies in Konfigurator!" ) );
+ KMessageBox::sorry( krApp, i18n( "Can't start root mode krusader, because krusader or tdesu is missing from the path. Please configure the dependencies in Konfigurator!" ) );
return;
}
KShellProcess proc;
- proc << KrServices::fullPathName( "kdesu" ) << TQString("'") + KrServices::fullPathName( "krusader" ) +
+ proc << KrServices::fullPathName( "tdesu" ) << TQString("'") + KrServices::fullPathName( "krusader" ) +
" --left=\"" +MAIN_VIEW->left->func->files()->vfs_getOrigin().url() +
"\" --right=\""+MAIN_VIEW->right->func->files()->vfs_getOrigin().url() + "\"'";
diff --git a/krusader/UserAction/kraction.cpp b/krusader/UserAction/kraction.cpp
index 2267b7d..2b9bbce 100644
--- a/krusader/UserAction/kraction.cpp
+++ b/krusader/UserAction/kraction.cpp
@@ -227,13 +227,13 @@ void KrActionProc::start( TQStringList cmdLineList ) {
if ( _action->user().isEmpty() )
( *_proc ) << term << cmd;
else
-// ( *_proc ) << "kdesu" << "-u" << *_properties->user() << "-c" << KProcess::quote("konsole --noclose -e " + KProcess::quote(cmd) );
- ( *_proc ) << "kdesu" << "-u" << _action->user() << "-c" << KProcess::quote( term + " " + cmd );
+// ( *_proc ) << "tdesu" << "-u" << *_properties->user() << "-c" << KProcess::quote("konsole --noclose -e " + KProcess::quote(cmd) );
+ ( *_proc ) << "tdesu" << "-u" << _action->user() << "-c" << KProcess::quote( term + " " + cmd );
} else { // no terminal, no output collection, start&forget
if ( _action->user().isEmpty() )
( *_proc ) << cmd;
else
- ( *_proc ) << "kdesu" << "-u" << _action->user() << "-c" << KProcess::quote(cmd);
+ ( *_proc ) << "tdesu" << "-u" << _action->user() << "-c" << KProcess::quote(cmd);
}
_proc->start( KProcess::NotifyOnExit, ( KProcess::Communication ) ( KProcess::Stdout | KProcess::Stderr ) );
}
@@ -259,8 +259,8 @@ void KrActionProc::start( TQStringList cmdLineList ) {
if ( _action->user().isEmpty() )
( *_proc ) << cmd;
else
- // "-t" is nessesary that kdesu displays the terminal-output of the command
- ( *_proc ) << "kdesu" << "-t" << "-u" << _action->user() << "-c" << KProcess::quote(cmd);
+ // "-t" is nessesary that tdesu displays the terminal-output of the command
+ ( *_proc ) << "tdesu" << "-t" << "-u" << _action->user() << "-c" << KProcess::quote(cmd);
_proc->start( KProcess::NotifyOnExit, ( KProcess::Communication ) ( KProcess::Stdout | KProcess::Stderr ) );
}